pub struct HttpConfig {
pub bind_addr: Option<String>,
pub admin_bind_addr: Option<String>,
pub max_connections: usize,
pub query_timeout: Duration,
pub request_timeout: Duration,
pub runtime: Option<SharedRuntime>,
}Expand description
Configuration for the HTTP server subsystem.
Fields
bind_addr: Option<String>Address to bind the HTTP server to (e.g., “0.0.0.0:8091”).
admin_bind_addr: Option<String>Address to bind the admin HTTP server to (e.g., “127.0.0.1:9091”). When set, admin operations are only available on this port. When not set, admin operations are not available.
max_connections: usizeMaximum number of concurrent connections.
query_timeout: DurationTimeout for query execution.
request_timeout: DurationTimeout for entire request lifecycle.
runtime: Option<SharedRuntime>Optional shared runtime .
Implementations
Sourceimpl HttpConfig
impl HttpConfig
Sourcepub fn admin_bind_addr(self, addr: impl Into<String>) -> Self
pub fn admin_bind_addr(self, addr: impl Into<String>) -> Self
Set the admin bind address. When set, admin operations are served on this separate port.
Sourcepub fn max_connections(self, max: usize) -> Self
pub fn max_connections(self, max: usize) -> Self
Set the maximum number of connections.
Sourcepub fn query_timeout(self, timeout: Duration) -> Self
pub fn query_timeout(self, timeout: Duration) -> Self
Set the query timeout.
Sourcepub fn request_timeout(self, timeout: Duration) -> Self
pub fn request_timeout(self, timeout: Duration) -> Self
Set the request timeout.
Sourcepub fn runtime(self, runtime: SharedRuntime) -> Self
pub fn runtime(self, runtime: SharedRuntime) -> Self
Set the shared runtime.